gmtmodernize: Convert GMT5 scripts to the new "modern" mode
===========================================================

.. image:: http://img.shields.io/pypi/v/gmtmodernize.svg?style=flat-square
    :alt: Latest version on PyPI
    :target: https://pypi.python.org/pypi/gmtmodernize
.. image:: http://img.shields.io/travis/GenericMappingTools/gmtmodernize/master.svg?style=flat-square
    :alt: Travis CI build status
    :target: https://travis-ci.org/GenericMappingTools/gmtmodernize
.. image:: http://img.shields.io/coveralls/GenericMappingTools/gmtmodernize/master.svg?style=flat-square
    :alt: Test coverage status
    :target: https://coveralls.io/r/GenericMappingTools/gmtmodernize?branch=master


This is **work in progress**. So far, it can convert some of the test and
example scripts from the GMT repository.

The code is in the Python script ``gmtmodernize``.
